[![Documentation Status](https://readthedocs.org/projects/veros-bgc/badge/?version=latest)](https://veros-bgc.readthedocs.io/en/latest/?badge=latest)

# Veros-BGC
A biogeochemistry plugin for Veros, based on MOBI.

## Quick usage

```bash
$ pip install veros veros-bgc
$ veros copy-setup bgc_global_4deg --to /tmp/bgc-4deg
$ cd /tmp/bgc-4deg
$ python bgc_global_four_degree.py
```

## Credits

Veros-BGC is based on [MOBI](http://people.oregonstate.edu/~schmita2/Models/MOBI/index.html) by [Andreas Schmittner](http://people.oregonstate.edu/~schmita2/), Oregon State University.

[Steffen Randrup](https://github.com/SteffenRandrup) created Veros-BGC as a part of his Master's thesis.
